package com.tiptimes.service.impl;


import com.alibaba.excel.EasyExcel;
import com.alibaba.excel.write.metadata.style.WriteCellStyle;
import com.alibaba.excel.write.metadata.style.WriteFont;
import com.alibaba.excel.write.style.HorizontalCellStyleStrategy;
import com.alibaba.excel.write.style.column.SimpleColumnWidthStyleStrategy;
import com.tiptimes.dao.QuestionnaireDao;
import com.tiptimes.model.Answer;
import com.tiptimes.model.PerformanceSummary;
import com.tiptimes.model.Record;
import com.tiptimes.model.Review;
import com.tiptimes.model.exportDTO.*;
import com.tiptimes.service.QuestionnaireService;
import org.apache.ibatis.annotations.Param;
import org.apache.poi.ss.usermodel.HorizontalAlignment;
import org.apache.poi.ss.usermodel.IndexedColors;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import java.util.List;


@Service
public class QuestionnaireServiceImpl implements QuestionnaireService {
    @Autowired
    private QuestionnaireDao questionnaireDao;

    /**
     * 根据上报人和问卷id查询上报记录id
     * @param questionnaireUuid 问卷id
     * @param createId 上报人唯一标识
     * @return
     */
    @Override
    @Transactional(readOnly = true)
    public Long selectRecordId(Long questionnaireUuid, String createId) {
        return questionnaireDao.selectRecordId(questionnaireUuid,createId);
    }

    /**
     * 添加上报记录
     * @param record 上报记录
     * @return
     */
    @Override
    @Transactional
    public Long insertRecord(Record record) {
        return questionnaireDao.insertRecord(record);
    }

    /**
     * 根据上报记录id删除原上报数据
     * @param recordId 上报记录id
     * @return
     */
    @Override
    @Transactional
    public Integer delAnswer(Long recordId) {
        return questionnaireDao.delAnswer(recordId);
    }

    /**
     * 添加上报数据
     * @param answerList
     * @param recordId
     * @return
     */
    @Override
    @Transactional
    public Integer insertAnswer(List<Answer> answerList, Long recordId) {
        return questionnaireDao.insertAnswer(answerList,recordId);
    }

    /**
     * 修改上报记录
     * @param record
     * @return
     */
    @Override
    @Transactional
    public Integer updateRecord(Record record) {
        return questionnaireDao.updateRecord(record);
    }

    /**
     * 通过记录id删除原有备注
     * @param recordId
     * @return
     */
    @Override
    @Transactional
    public Integer delView(Long recordId) {
        return questionnaireDao.delView(recordId);
    }

    /**
     * 添加新的备注
     * @param review
     * @return
     */
    @Override
    @Transactional
    public Integer insertReview(List<Review> review,Long recordId) {
        return questionnaireDao.insertReview(review,recordId);
    }

    /**
     * 通过记录id删除原有备注
     * @param recordId
     * @return
     */
    @Override
    public List<Answer> selectAnswerByRecordId(Long recordId) {
        return questionnaireDao.selectAnswerByRecordId(recordId);
    }

    /**
     * 根据记录id查询评审备注详情
     * @param recordId 记录id
     * @return
     */
    @Override
    public List<Review> selectReviewByRecordId(Long recordId) {
        return questionnaireDao.selectReviewByRecordId(recordId);
    }

    @Override
    public Record selectById(Long recordId) {
        return questionnaireDao.selectById(recordId);
    }

    /**
     * 按条件查询上报记录
     * @param record 筛选条件
     * @return
     */
    @Override
    public List<Record> selectRecordList(Record record) {
        return questionnaireDao.selectRecordList(record);
    }

    @Override
    public List<String> selectFileId(Long optionId, Long recordId) {
        return questionnaireDao.selectFileId(optionId,recordId);
    }

    @Override
    public List<PerformanceSummary> selectPerformanceSummaryList(PerformanceSummary performanceSummary){
        return questionnaireDao.selectPerformanceSummaryList(performanceSummary);
    }

    /**
     * 2022年10月新增加功能问卷管理-审批页面根据基础指标、引导指标和奖励指标导出所有空间的数据
     * @param request
     * @param response
     * @param index 区分指标
     * @param recordId 上报记录id
     */
    @Override
    public void exportFullTimeWorkPerson(HttpServletRequest request, HttpServletResponse response, String index, String recordId){
        try {
            WriteCellStyle headWriteCellStyle = new WriteCellStyle();
            //设置背景颜色
            headWriteCellStyle.setFillForegroundColor(IndexedColors.GREY_25_PERCENT.getIndex());
            //设置头字体
            WriteFont headWriteFont = new WriteFont();
            headWriteFont.setFontHeightInPoints((short) 10);
            headWriteFont.setBold(true);
            headWriteCellStyle.setWriteFont(headWriteFont);
            //设置头居中
            headWriteCellStyle.setHorizontalAlignment(HorizontalAlignment.CENTER);
            //内容策略
            WriteCellStyle contentWriteCellStyle = new WriteCellStyle();
            contentWriteCellStyle.setWrapped(true);
            //设置 水平居中
            contentWriteCellStyle.setHorizontalAlignment(HorizontalAlignment.CENTER);
            HorizontalCellStyleStrategy horizontalCellStyleStrategy = new HorizontalCellStyleStrategy(headWriteCellStyle, contentWriteCellStyle);

            response.setContentType("application/vnd.ms-excel;charset=UTF-8");
            response.setCharacterEncoding("UTF-8");

            switch (index) {
                case "1":
                    //导出文件名称
                    String fileName_a = "基础指标一";
                    response.setHeader("Content-disposition", "attachment;filename=" + new String((fileName_a).getBytes("gb2312"), "ISO-8859-1") + ".xlsx");
                    //查询数据
                    List<FullTimeWorkPerson> fullTimeWorkPersonList = questionnaireDao.selectFullTimeWorkPersonList(recordId);
                    if (fullTimeWorkPersonList != null) {
                        for(int i = 0; i < fullTimeWorkPersonList.size();i++){
                            //excel生成序号
                            fullTimeWorkPersonList.get(i).setIndex(i+1);
                        }
                        //生成excel
                        EasyExcel.write(response.getOutputStream(),FullTimeWorkPerson.class).sheet("众创空间场地情况").
                                registerWriteHandler(horizontalCellStyleStrategy)
                                .registerWriteHandler(new SimpleColumnWidthStyleStrategy(30))
                                .doWrite(fullTimeWorkPersonList);
                        response.flushBuffer();
                    }
                    break;
                case "2":
                    //导出文件名称
                    String fileName_b = "基础指标二";
                    response.setHeader("Content-disposition", "attachment;filename=" + new String((fileName_b).getBytes("gb2312"), "ISO-8859-1") + ".xlsx");
                    //查询数据
                    List<SiteCondition> siteConditionList = questionnaireDao.selectSiteConditionList();
                    if (siteConditionList != null) {
                        for(int i = 0; i < siteConditionList.size();i++){
                            //excel生成序号
                            siteConditionList.get(i).setIndex(i+1);
                        }
                        //生成excel
                        EasyExcel.write(response.getOutputStream(),SiteCondition.class).sheet("众创空间场地情况与是否租赁场地").
                                registerWriteHandler(horizontalCellStyleStrategy)
                                .registerWriteHandler(new SimpleColumnWidthStyleStrategy(30))
                                .doWrite(siteConditionList);
                        response.flushBuffer();
                    }
                    break;
                case "3":
                    //导出文件名称
                    String fileName_c = "基础指标三";
                    response.setHeader("Content-disposition", "attachment;filename=" + new String((fileName_c).getBytes("gb2312"), "ISO-8859-1") + ".xlsx");
                    //查询数据
                    List<IncubatedEnterprises> incubatedEnterprisesList = questionnaireDao.selectIncubatedEnterprisesList();
                    if (incubatedEnterprisesList != null) {
                        for(int i = 0; i < incubatedEnterprisesList.size();i++){
                            //excel生成序号
                            incubatedEnterprisesList.get(i).setIndex(i+1);
                        }
                        //生成excel
                        EasyExcel.write(response.getOutputStream(),IncubatedEnterprises.class).sheet("入孵企业情况").
                                registerWriteHandler(horizontalCellStyleStrategy)
                                .registerWriteHandler(new SimpleColumnWidthStyleStrategy(30))
                                .doWrite(incubatedEnterprisesList);
                        response.flushBuffer();
                    }
                    break;
                case "4":
                    //导出文件名称
                    String fileName_d = "基础指标四";
                    response.setHeader("Content-disposition", "attachment;filename=" + new String((fileName_d).getBytes("gb2312"), "ISO-8859-1") + ".xlsx");
                    //查询数据
                    List<EmploymentSituation> employmentSituationList = questionnaireDao.selectEmploymentSituationList();
                    if (employmentSituationList != null) {
                        for(int i = 0; i < employmentSituationList.size();i++){
                            //excel生成序号
                            employmentSituationList.get(i).setIndex(i+1);
                        }
                        //生成excel
                        EasyExcel.write(response.getOutputStream(),EmploymentSituation.class).sheet("新增就业情况").
                                registerWriteHandler(horizontalCellStyleStrategy)
                                .registerWriteHandler(new SimpleColumnWidthStyleStrategy(30))
                                .doWrite(employmentSituationList);
                        response.flushBuffer();
                    }
                    break;
                case "5":
                    //导出文件名称
                    String fileName_e = "基础指标五";
                    response.setHeader("Content-disposition", "attachment;filename=" + new String((fileName_e).getBytes("gb2312"), "ISO-8859-1") + ".xlsx");
                    //查询数据
                    List<EntrepreneurshipCourses> entrepreneurshipCoursesList = questionnaireDao.selectEntrepreneurshipCoursesList();
                    if (entrepreneurshipCoursesList != null) {
                        for(int i = 0; i < entrepreneurshipCoursesList.size();i++){
                            //excel生成序号
                            entrepreneurshipCoursesList.get(i).setIndex(i+1);
                        }
                        //生成excel
                        EasyExcel.write(response.getOutputStream(),EntrepreneurshipCourses.class).sheet("开设创新创业课程情况").
                                registerWriteHandler(horizontalCellStyleStrategy)
                                .registerWriteHandler(new SimpleColumnWidthStyleStrategy(30))
                                .doWrite(entrepreneurshipCoursesList);
                        response.flushBuffer();
                    }
                    break;
                case "6":
                    //导出文件名称
                    String fileName_f = "基础指标六";
                    response.setHeader("Content-disposition", "attachment;filename=" + new String((fileName_f).getBytes("gb2312"), "ISO-8859-1") + ".xlsx");
                    //查询数据
                    List<SigningMentors> signingMentorsList = questionnaireDao.selectSigningMentorsList();
                    if (signingMentorsList != null) {
                        for(int i = 0; i < signingMentorsList.size();i++){
                            //excel生成序号
                            signingMentorsList.get(i).setIndex(i+1);
                        }
                        //生成excel
                        EasyExcel.write(response.getOutputStream(),SigningMentors.class).sheet("签约创业导师情况").
                                registerWriteHandler(horizontalCellStyleStrategy)
                                .registerWriteHandler(new SimpleColumnWidthStyleStrategy(30))
                                .doWrite(signingMentorsList);
                        response.flushBuffer();
                    }
                    break;
                case "7":
                    //导出文件名称
                    String fileName_g = "基础指标七";
                    response.setHeader("Content-disposition", "attachment;filename=" + new String((fileName_g).getBytes("gb2312"), "ISO-8859-1") + ".xlsx");
                    //查询数据
                    List<OrganizationActivity> organizationActivityList = questionnaireDao.selectOrganizationActivityList();
                    if (organizationActivityList != null) {
                        for(int i = 0; i < organizationActivityList.size();i++){
                            //excel生成序号
                            organizationActivityList.get(i).setIndex(i+1);
                        }
                        //生成excel
                        EasyExcel.write(response.getOutputStream(),OrganizationActivity.class).sheet("组织双创活动情况").
                                registerWriteHandler(horizontalCellStyleStrategy)
                                .registerWriteHandler(new SimpleColumnWidthStyleStrategy(30))
                                .doWrite(organizationActivityList);
                        response.flushBuffer();
                    }
                    break;
                case "8":
                    //导出文件名称
                    String fileName_h = "基础指标八";
                    response.setHeader("Content-disposition", "attachment;filename=" + new String((fileName_h).getBytes("gb2312"), "ISO-8859-1") + ".xlsx");
                    //查询数据
                    List<CompetingSituation> competingSituationList = questionnaireDao.selectCompetingSituationList();
                    if (competingSituationList != null) {
                        for(int i = 0; i < competingSituationList.size();i++){
                            //excel生成序号
                            competingSituationList.get(i).setIndex(i+1);
                        }
                        //生成excel
                        EasyExcel.write(response.getOutputStream(),CompetingSituation.class).sheet("参赛情况").
                                registerWriteHandler(horizontalCellStyleStrategy)
                                .registerWriteHandler(new SimpleColumnWidthStyleStrategy(30))
                                .doWrite(competingSituationList);
                        response.flushBuffer();
                    }
                    break;
                case "9":
                    //导出文件名称
                    String fileName_j = "基础指标九";
                    response.setHeader("Content-disposition", "attachment;filename=" + new String((fileName_j).getBytes("gb2312"), "ISO-8859-1") + ".xlsx");
                    //查询数据
                    List<EntrepreneurshipFunding> entrepreneurshipFundingList = questionnaireDao.selectEntrepreneurshipFundingList();
                    if (entrepreneurshipFundingList != null) {
                        for(int i = 0; i < entrepreneurshipFundingList.size();i++){
                            //excel生成序号
                            entrepreneurshipFundingList.get(i).setIndex(i+1);
                        }
                        //生成excel
                        EasyExcel.write(response.getOutputStream(),EntrepreneurshipFunding.class).sheet("创新创业工作经费").
                                registerWriteHandler(horizontalCellStyleStrategy)
                                .registerWriteHandler(new SimpleColumnWidthStyleStrategy(30))
                                .doWrite(entrepreneurshipFundingList);
                        response.flushBuffer();
                    }
                    break;
                case "10":
                    //引导指标1 --基础指标1
                    //导出文件名称
                    String fileName_aa = "引导指标一";
                    response.setHeader("Content-disposition", "attachment;filename=" + new String((fileName_aa).getBytes("gb2312"), "ISO-8859-1") + ".xlsx");
                    //查询数据
                    List<FullTimeWorkPerson> leadingIndicatorOneList = questionnaireDao.selectFullTimeWorkPersonList(recordId);
                    if (leadingIndicatorOneList != null) {
                        for(int i = 0; i < leadingIndicatorOneList.size();i++){
                            //excel生成序号
                            leadingIndicatorOneList.get(i).setIndex(i+1);
                        }
                        //生成excel
                        EasyExcel.write(response.getOutputStream(),FullTimeWorkPerson.class).sheet("引导指标一").
                                registerWriteHandler(horizontalCellStyleStrategy)
                                .registerWriteHandler(new SimpleColumnWidthStyleStrategy(30))
                                .doWrite(leadingIndicatorOneList);
                        response.flushBuffer();
                    }
                    break;
                case "11":
                    //引导指标2 --基础指标1
                    //导出文件名称
                    String fileName_bb = "引导指标二";
                    response.setHeader("Content-disposition", "attachment;filename=" + new String((fileName_bb).getBytes("gb2312"), "ISO-8859-1") + ".xlsx");
                    //查询数据
                    List<FullTimeWorkPerson> leadingIndicatorTwoList = questionnaireDao.selectFullTimeWorkPersonList(recordId);
                    if (leadingIndicatorTwoList != null) {
                        for(int i = 0; i < leadingIndicatorTwoList.size();i++){
                            //excel生成序号
                            leadingIndicatorTwoList.get(i).setIndex(i+1);
                        }
                        //生成excel
                        EasyExcel.write(response.getOutputStream(),FullTimeWorkPerson.class).sheet("引导指标二").
                                registerWriteHandler(horizontalCellStyleStrategy)
                                .registerWriteHandler(new SimpleColumnWidthStyleStrategy(30))
                                .doWrite(leadingIndicatorTwoList);
                        response.flushBuffer();
                    }
                    break;
                case "12":
                    //引导指标3 --基础指标3
                    //导出文件名称
                    String fileName_cc = "引导指标三";
                    response.setHeader("Content-disposition", "attachment;filename=" + new String((fileName_cc).getBytes("gb2312"), "ISO-8859-1") + ".xlsx");
                    //查询数据
                    List<IncubatedEnterprises> leadingIndicatorThreeList = questionnaireDao.selectIncubatedEnterprisesList();
                    if (leadingIndicatorThreeList != null) {
                        for(int i = 0; i < leadingIndicatorThreeList.size();i++){
                            //excel生成序号
                            leadingIndicatorThreeList.get(i).setIndex(i+1);
                        }
                        //生成excel
                        EasyExcel.write(response.getOutputStream(),IncubatedEnterprises.class).sheet("引导指标三").
                                registerWriteHandler(horizontalCellStyleStrategy)
                                .registerWriteHandler(new SimpleColumnWidthStyleStrategy(30))
                                .doWrite(leadingIndicatorThreeList);
                        response.flushBuffer();
                    }
                    break;
                case "13":
                    //引导指标4 --基础指标3
                    //导出文件名称
                    String fileName_dd = "引导指标四";
                    response.setHeader("Content-disposition", "attachment;filename=" + new String((fileName_dd).getBytes("gb2312"), "ISO-8859-1") + ".xlsx");
                    //查询数据
                    List<IncubatedEnterprises> leadingIndicatorFoureList = questionnaireDao.selectIncubatedEnterprisesList();
                    if (leadingIndicatorFoureList != null) {
                        for(int i = 0; i < leadingIndicatorFoureList.size();i++){
                            //excel生成序号
                            leadingIndicatorFoureList.get(i).setIndex(i+1);
                        }
                        //生成excel
                        EasyExcel.write(response.getOutputStream(),IncubatedEnterprises.class).sheet("引导指标四").
                                registerWriteHandler(horizontalCellStyleStrategy)
                                .registerWriteHandler(new SimpleColumnWidthStyleStrategy(30))
                                .doWrite(leadingIndicatorFoureList);
                        response.flushBuffer();
                    }
                    break;
                case "14":
                    //引导指标5 --基础指标4
                    //导出文件名称
                    String fileName_ee = "引导指标五";
                    response.setHeader("Content-disposition", "attachment;filename=" + new String((fileName_ee).getBytes("gb2312"), "ISO-8859-1") + ".xlsx");
                    //查询数据
                    List<SigningMentors> leadingIndicatorFiveList = questionnaireDao.selectSigningMentorsList();
                    if (leadingIndicatorFiveList != null) {
                        for(int i = 0; i < leadingIndicatorFiveList.size();i++){
                            //excel生成序号
                            leadingIndicatorFiveList.get(i).setIndex(i+1);
                        }
                        //生成excel
                        EasyExcel.write(response.getOutputStream(),SigningMentors.class).sheet("引导指标五").
                                registerWriteHandler(horizontalCellStyleStrategy)
                                .registerWriteHandler(new SimpleColumnWidthStyleStrategy(30))
                                .doWrite(leadingIndicatorFiveList);
                        response.flushBuffer();
                    }
                    break;
                case "15":
                    //引导指标6
                    //导出文件名称
                    String fileName_k = "引导指标六";
                    response.setHeader("Content-disposition", "attachment;filename=" + new String((fileName_k).getBytes("gb2312"), "ISO-8859-1") + ".xlsx");
                    //查询数据
                    List<EntrepreneurshipProject> entrepreneurshipProjectList = questionnaireDao.selectEntrepreneurshipProjectList();
                    if (entrepreneurshipProjectList != null) {
                        for(int i = 0; i < entrepreneurshipProjectList.size();i++){
                            //excel生成序号
                            entrepreneurshipProjectList.get(i).setIndex(i+1);
                        }
                        //生成excel
                        EasyExcel.write(response.getOutputStream(),EntrepreneurshipProject.class).sheet("申报成功高校众创空间联盟发布的创新创业研究课题信息").
                                registerWriteHandler(horizontalCellStyleStrategy)
                                .registerWriteHandler(new SimpleColumnWidthStyleStrategy(30))
                                .doWrite(entrepreneurshipProjectList);
                        response.flushBuffer();
                    }
                    break;
                case "16":
                    //引导指标7 --基础指标6
                    //导出文件名称
                    String fileName_ff = "引导指标七";
                    response.setHeader("Content-disposition", "attachment;filename=" + new String((fileName_ff).getBytes("gb2312"), "ISO-8859-1") + ".xlsx");
                    //查询数据
                    List<SigningMentors> leadingIndicatorSixList = questionnaireDao.selectSigningMentorsList();
                    if (leadingIndicatorSixList != null) {
                        for(int i = 0; i < leadingIndicatorSixList.size();i++){
                            //excel生成序号
                            leadingIndicatorSixList.get(i).setIndex(i+1);
                        }
                        //生成excel
                        EasyExcel.write(response.getOutputStream(),SigningMentors.class).sheet("引导指标七").
                                registerWriteHandler(horizontalCellStyleStrategy)
                                .registerWriteHandler(new SimpleColumnWidthStyleStrategy(30))
                                .doWrite(leadingIndicatorSixList);
                        response.flushBuffer();
                    }
                    break;
                case "17":
                    //引导指标8 --基础指标7
                    //导出文件名称
                    String fileName_gg = "引导指标八";
                    response.setHeader("Content-disposition", "attachment;filename=" + new String((fileName_gg).getBytes("gb2312"), "ISO-8859-1") + ".xlsx");
                    //查询数据
                    List<OrganizationActivity> leadingIndicatorSevenList = questionnaireDao.selectOrganizationActivityList();
                    if (leadingIndicatorSevenList != null) {
                        for(int i = 0; i < leadingIndicatorSevenList.size();i++){
                            //excel生成序号
                            leadingIndicatorSevenList.get(i).setIndex(i+1);
                        }
                        //生成excel
                        EasyExcel.write(response.getOutputStream(),OrganizationActivity.class).sheet("引导指标八").
                                registerWriteHandler(horizontalCellStyleStrategy)
                                .registerWriteHandler(new SimpleColumnWidthStyleStrategy(30))
                                .doWrite(leadingIndicatorSevenList);
                        response.flushBuffer();
                    }
                    break;
                case "18":
                    //引导指标9
                    //导出文件名称
                    String fileName_l = "引导指标九";
                    response.setHeader("Content-disposition", "attachment;filename=" + new String((fileName_l).getBytes("gb2312"), "ISO-8859-1") + ".xlsx");
                    //查询数据
                    List<EnterprisestAmount> enterprisestAmountList = questionnaireDao.selecEnterprisestAmountList();
                    if (enterprisestAmountList != null) {
                        for(int i = 0; i < enterprisestAmountList.size();i++){
                            //excel生成序号
                            enterprisestAmountList.get(i).setIndex(i+1);
                        }
                        //生成excel
                        EasyExcel.write(response.getOutputStream(),EnterprisestAmount.class).sheet("在孵企业销售收入或累计合同额情况").
                                registerWriteHandler(horizontalCellStyleStrategy)
                                .registerWriteHandler(new SimpleColumnWidthStyleStrategy(30))
                                .doWrite(enterprisestAmountList);
                        response.flushBuffer();
                    }
                    break;
                case "19":
                    //引导指标10
                    //导出文件名称
                    String fileName_z = "引导指标十";
                    response.setHeader("Content-disposition", "attachment;filename=" + new String((fileName_z).getBytes("gb2312"), "ISO-8859-1") + ".xlsx");
                    //查询数据
                    List<EvaluationBorrowing> evaluationBorrowingList = questionnaireDao.selectEvaluationBorrowingList();
                    if (evaluationBorrowingList != null) {
                        for(int i = 0; i < evaluationBorrowingList.size();i++){
                            //excel生成序号
                            evaluationBorrowingList.get(i).setIndex(i+1);
                        }
                        //生成excel
                        EasyExcel.write(response.getOutputStream(),EvaluationBorrowing.class).sheet("本评估周期实现股权或债权融资情况").
                                registerWriteHandler(horizontalCellStyleStrategy)
                                .registerWriteHandler(new SimpleColumnWidthStyleStrategy(30))
                                .doWrite(evaluationBorrowingList);
                        response.flushBuffer();
                    }
                    break;
                case "20":
                    //引导指标11
                    //导出文件名称
                    String fileName_x = "引导指标十一";
                    response.setHeader("Content-disposition", "attachment;filename=" + new String((fileName_x).getBytes("gb2312"), "ISO-8859-1") + ".xlsx");
                    //查询数据
                    List<InnovationWeek> innovationWeekList = questionnaireDao.selectInnovationWeekList();
                    if (innovationWeekList != null) {
                        for(int i = 0; i < innovationWeekList.size();i++){
                            //excel生成序号
                            innovationWeekList.get(i).setIndex(i+1);
                        }
                        //生成excel
                        EasyExcel.write(response.getOutputStream(),InnovationWeek.class).sheet("主办或承办市级及以上级别路演、双创周活动").
                                registerWriteHandler(horizontalCellStyleStrategy)
                                .registerWriteHandler(new SimpleColumnWidthStyleStrategy(30))
                                .doWrite(innovationWeekList);
                        response.flushBuffer();
                    }
                    break;
                case "21":
                    //引导指标12
                    //导出文件名称
                    String fileName_v = "引导指标十二";
                    response.setHeader("Content-disposition", "attachment;filename=" + new String((fileName_v).getBytes("gb2312"), "ISO-8859-1") + ".xlsx");
                    //查询数据
                    List<CollegeSituation> collegeSituationList = questionnaireDao.selectCollegeSituationList();
                    if (collegeSituationList != null) {
                        for(int i = 0; i < collegeSituationList.size();i++){
                            //excel生成序号
                            collegeSituationList.get(i).setIndex(i+1);
                        }
                        //生成excel
                        EasyExcel.write(response.getOutputStream(),CollegeSituation.class).sheet("在孵企业在OTC高校板挂牌情况").
                                registerWriteHandler(horizontalCellStyleStrategy)
                                .registerWriteHandler(new SimpleColumnWidthStyleStrategy(30))
                                .doWrite(collegeSituationList);
                        response.flushBuffer();
                    }
                    break;
                case "22":
                    //引导指标13
                    //导出文件名称
                    String fileName_o = "引导指标十三";
                    response.setHeader("Content-disposition", "attachment;filename=" + new String((fileName_o).getBytes("gb2312"), "ISO-8859-1") + ".xlsx");
                    //查询数据
                    List<EnterprisesIntellectual> enterprisesIntellectualList = questionnaireDao.selectEnterprisesIntellectualList();
                    if (enterprisesIntellectualList != null) {
                        for(int i = 0; i < enterprisesIntellectualList.size();i++){
                            //excel生成序号
                            enterprisesIntellectualList.get(i).setIndex(i+1);
                        }
                        //生成excel
                        EasyExcel.write(response.getOutputStream(),EnterprisesIntellectual.class).sheet("在孵企业新增知识产权").
                                registerWriteHandler(horizontalCellStyleStrategy)
                                .registerWriteHandler(new SimpleColumnWidthStyleStrategy(30))
                                .doWrite(enterprisesIntellectualList);
                        response.flushBuffer();
                    }
                    break;
                case "23":
                    //奖励指标1
                    //导出文件名称
                    String fileName_p = "奖励指标一";
                    response.setHeader("Content-disposition", "attachment;filename=" + new String((fileName_p).getBytes("gb2312"), "ISO-8859-1") + ".xlsx");
                    //查询数据
                    List<NationalCompetitionAwards> nationalCompetitionAwardsList = questionnaireDao.selectNationalCompetitionAwardsList();
                    if (nationalCompetitionAwardsList != null) {
                        for(int i = 0; i < nationalCompetitionAwardsList.size();i++){
                            //excel生成序号
                            nationalCompetitionAwardsList.get(i).setIndex(i+1);
                        }
                        //生成excel
                        EasyExcel.write(response.getOutputStream(),NationalCompetitionAwards.class).sheet("获得“互联网+”大赛全国赛事奖项情况").
                                registerWriteHandler(horizontalCellStyleStrategy)
                                .registerWriteHandler(new SimpleColumnWidthStyleStrategy(30))
                                .doWrite(nationalCompetitionAwardsList);
                        response.flushBuffer();
                    }
                    break;
                case "24":
                    //奖励指标2
                    //导出文件名称
                    String fileName_n = "奖励指标二";
                    response.setHeader("Content-disposition", "attachment;filename=" + new String((fileName_n).getBytes("gb2312"), "ISO-8859-1") + ".xlsx");
                    //查询数据
                    List<EducationCommission> educationCommissionList = questionnaireDao.selectEducationCommissionList();
                    if (educationCommissionList != null) {
                        for(int i = 0; i < educationCommissionList.size();i++){
                            //excel生成序号
                            educationCommissionList.get(i).setIndex(i+1);
                        }
                        //生成excel
                        EasyExcel.write(response.getOutputStream(),EducationCommission.class).sheet("获得创客马拉松大赛及市教委组织的其他双创大赛奖项情况").
                                registerWriteHandler(horizontalCellStyleStrategy)
                                .registerWriteHandler(new SimpleColumnWidthStyleStrategy(30))
                                .doWrite(educationCommissionList);
                        response.flushBuffer();
                    }
                    break;
                case "25":
                    //奖励指标3
                    //导出文件名称
                    String fileName_m = "奖励指标三";
                    response.setHeader("Content-disposition", "attachment;filename=" + new String((fileName_m).getBytes("gb2312"), "ISO-8859-1") + ".xlsx");
                    //查询数据
                    List<EntrepreneurialProject> entrepreneurialProjectList = questionnaireDao.selectEntrepreneurialProjectList();
                    if (entrepreneurialProjectList != null) {
                        for(int i = 0; i < entrepreneurialProjectList.size();i++){
                            //excel生成序号
                            entrepreneurialProjectList.get(i).setIndex(i+1);
                        }
                        //生成excel
                        EasyExcel.write(response.getOutputStream(),EntrepreneurialProject.class).sheet("入选天津市创业拔尖项目情况").
                                registerWriteHandler(horizontalCellStyleStrategy)
                                .registerWriteHandler(new SimpleColumnWidthStyleStrategy(30))
                                .doWrite(entrepreneurialProjectList);
                        response.flushBuffer();
                    }
                    break;
                case "26":
                    //奖励指标4-奖励指标5
                    //奖励指标3
                    //导出文件名称
                    String fileName_u = "奖励指标四";
                    response.setHeader("Content-disposition", "attachment;filename=" + new String((fileName_u).getBytes("gb2312"), "ISO-8859-1") + ".xlsx");
                    //查询数据
                    List<SpaceAndIncubation> spaceAndIncubationList = questionnaireDao.selectSpaceAndIncubationList();
                    if (spaceAndIncubationList != null) {
                        for(int i = 0; i < spaceAndIncubationList.size();i++){
                            //excel生成序号
                            spaceAndIncubationList.get(i).setIndex(i+1);
                        }
                        //生成excel
                        EasyExcel.write(response.getOutputStream(),SpaceAndIncubation.class).sheet("是否为国家级备案众创空间").
                                registerWriteHandler(horizontalCellStyleStrategy)
                                .registerWriteHandler(new SimpleColumnWidthStyleStrategy(30))
                                .doWrite(spaceAndIncubationList);
                        response.flushBuffer();
                    }
                    break;
                default:
                    break;
            }

        } catch (Exception e) {
            e.printStackTrace();
        }
    }
}
